/*
 * A header file for a progress dialog used with the RNAstructure GUI.
 *
 * (c) 2009  Mathews Lab, University of Rochester Medical Center
 * Written by Jessica Reuter
 */

#ifndef SWIG_TPROGRESSDIALOG_H
#define SWIG_TPROGRESSDIALOG_H

#include "ProgressMonitor.h"

class TProgressDialog {
 public:
  // Public constructor and method

  /*
   * Name:        Constructor
   * Description: Constructs the TProgressDialog proxy object.
   * Argument:
   *          1. A reference to a ProgressMonitor
   */
  TProgressDialog( ProgressMonitor& monitor );

  // A virtual method is required to cause this class to be polymorphic (i.e. have a vtable), which is required for ObservingTextProgressBar
  virtual ~TProgressDialog();

  /*
   * Name:        update
   * Description: Updates the underlying C++ class.
   * Argument:
   *     1.   The new percent value the underlying C++ class should hold.
   */
  void update( int percent );

  /*
   * Name:        canceled
   * Description: returns true if the operation was canceled by the user.
   */
  bool canceled();

  /*
   * Name:        progress
   * Description: returns the current progress percent.
   */
  int progress();

 private:
  // The progress monitor
  ProgressMonitor* progressMonitor;
};

#endif /* SWIG_TPROGRESS_DIALOG_H */
